#!/usr/bin/env python3
#
# SPDX-License-Identifier: MIT
#


import os
import sys
import subprocess
import threading
import time
import logging
import re
import contextlib
import errno
import datetime

        
class datastore(object):
    def __init__(self):
        self.ds = {}
        self.ds['DATETIME'] = datetime.datetime.now().strftime('%Y%m%d%H%M%S')
        self.ds['PN'] = "core-image-minimal"
        self.ds['IMAGE_FSTYPES'] = "ext4"
        self.ds['DEPLOY_DIR_IMAGE'] = "/media/build/poky/build/tmp/deploy/images/qemux86-64/"
        self.ds['IMAGE_LINK_NAME'] = "core-image-minimal-qemux86-64.rootfs"
        self.ds['KERNEL_IMAGETYPE'] = 'bzImage'
        self.ds['TESTIMAGE_DUMP_DIR'] = './'
        self.ds['TEST_LOG_DIR'] = './'
        self.ds['TMPDIR'] = './'
        self.ds['MACHINE'] = 'qemux86-64'
        self.ds['DISTRO'] = 'poky'
        self.ds['RUNQEMU_TMPFS_DIR'] = './'
        self.ds['SERIAL_CONSOLES'] = '115200;ttyS0 115200;ttyS1'
        self.ds['testimage_dump_target'] = False
        self.ds['testimage_dump_monitor'] = False

    def getVar(self, var, ignore=None):
        return self.ds[var]
    def setVar(self, var, value):
        self.ds[var] = value

def runqemu2():
    pn = "core-image-minimal"
    ssh=True
    runqemuparams = ''
    image_fstype = None
    launch_cmd = None
    qemuparams=None
    overrides={}
    discard_writes=True

    # Need a non-'BitBake' logger to capture the runner output
    targetlogger = logging.getLogger('TargetRunner')
    targetlogger.setLevel(logging.DEBUG)
    handler = logging.StreamHandler(sys.stdout)
    targetlogger.addHandler(handler)

    if 1:

        import targetcontrol
        recipedata = datastore()
        recipedata.setVar("TEST_QEMUBOOT_TIMEOUT", "1000")
        # Tell QemuTarget() whether need find rootfs/kernel or not
        if launch_cmd:
            recipedata.setVar("FIND_ROOTFS", '0')
        else:
            recipedata.setVar("FIND_ROOTFS", '1')

        for key, value in overrides.items():
            recipedata.setVar(key, value)

        logdir = recipedata.getVar("TEST_LOG_DIR")

        qemu = targetcontrol.QemuTarget(recipedata, targetlogger, image_fstype)

    try:
        qemu.deploy()
        try:
            qemu.start(params=qemuparams, ssh=ssh, runqemuparams=runqemuparams, launch_cmd=launch_cmd, discard_writes=discard_writes)
        except Exception as e:
            msg = str(e) + '\nFailed to start QEMU - see the logs in %s' % logdir
            if os.path.exists(qemu.qemurunnerlog):
                with open(qemu.qemurunnerlog, 'r') as f:
                    msg = msg + "Qemurunner log output from %s:\n%s" % (qemu.qemurunnerlog, f.read())
            raise Exception(msg)

        #yield qemu

    finally:
        targetlogger.removeHandler(handler)
        qemu.stop()

runqemu2()


